@@ -48,11 +48,15 @@ pub struct Module {
 }
 
 impl Default for Module {
-    fn default() -> Self { Module::create(None, "") }
+    fn default() -> Self {
+        Module::create(None, "")
+    }
 }
 
 impl Module {
-    pub fn new_with_name(name: &str) -> Self { Module::create(None, name) }
+    pub fn new_with_name(name: &str) -> Self {
+        Module::create(None, name)
+    }
 
     pub fn create(module_id: Option<i64>, module_name: &str) -> Self {
         let args: Vec<String> = env::args().collect();
@@ -135,7 +139,9 @@ impl Module {
         }
     }
 
-    pub fn new() -> Self { Module::create(None, "") }
+    pub fn new() -> Self {
+        Module::create(None, "")
+    }
 
     pub fn get_property(param: &str) -> Option<String> {
         let args: Vec<String> = env::args().collect();
@@ -284,8 +290,8 @@ impl Module {
                         error!("heartbeat: found fatal error, stop listen queue");
                         break;
                     }
-                },
-                _ => {},
+                }
+                _ => {}
             }
 
             if let Some(s) = self.connect_to_notify_channel() {
@@ -326,16 +332,16 @@ impl Module {
                     match e {
                         ErrorQueue::FailReadTailMessage => {
                             break;
-                        },
+                        }
                         ErrorQueue::InvalidChecksum => {
                             error!("[module] consumer:pop_body: invalid CRC, attempt seek next record");
                             queue_consumer.seek_next_pos();
                             break;
-                        },
+                        }
                         _ => {
                             error!("{} get msg from queue: {}", self.queue_prepared_count, e.as_str());
                             break;
-                        },
+                        }
                     }
                 }
 
@@ -348,10 +354,10 @@ impl Module {
                                 warn!("prepare: found fatal error, stop listen queue");
                                 return;
                             }
-                        },
+                        }
                         Ok(b) => {
                             need_commit = b;
-                        },
+                        }
                     }
                 }
 
@@ -378,10 +384,10 @@ impl Module {
                                         warn!("prepare: found fatal error, stop listen queue");
                                         return;
                                     }
-                                },
+                                }
                                 Ok(b) => {
                                     need_commit = b;
-                                },
+                                }
                             }
                         }
                     }
@@ -403,13 +409,13 @@ impl Module {
                         if b {
                             queue_consumer.commit();
                         }
-                    },
+                    }
                     Err(e) => {
                         if let PrepareError::Fatal = e {
                             warn!("after_batch: found fatal error, stop listen queue");
                             return;
                         }
-                    },
+                    }
                 }
             }
 
@@ -464,9 +470,15 @@ pub fn get_cmd(queue_element: &mut Individual) -> Option<IndvOp> {
     Some(IndvOp::from_i64(wcmd.unwrap_or_default()))
 }
 
-pub fn init_log(module_name: &str) { init_log_with_filter(module_name, None) }
+pub fn init_log(module_name: &str) {
+    init_log_with_filter(module_name, None)
+}
 
 pub fn init_log_with_filter(module_name: &str, filter: Option<&str>) {
+    init_log_with_params(module_name, filter, false);
+}
+
+pub fn init_log_with_params(module_name: &str, filter: Option<&str>, with_thread_id: bool) {
     let var_log_name = module_name.to_owned() + "_LOG";
     match std::env::var_os(var_log_name.to_owned()) {
         Some(val) => println!("use env var: {}: {:?}", var_log_name, val.to_str()),
@@ -479,11 +491,19 @@ pub fn init_log_with_filter(module_name: &str, filter: Option<&str>) {
         env::var(var_log_name).unwrap_or_default()
     };
 
-    Builder::new()
-        .format(|buf, record| writeln!(buf, "{} [{}] - {}", Local::now().format("%Y-%m-%dT%H:%M:%S%.3f"), record.level(), record.args()))
-        .parse_filters(&filters_str)
-        .try_init()
-        .unwrap_or(())
+    if with_thread_id {
+        Builder::new()
+            .format(|buf, record| writeln!(buf, "{} {} [{}] - {}", thread_id::get(), Local::now().format("%Y-%m-%dT%H:%M:%S%.3f"), record.level(), record.args()))
+            .parse_filters(&filters_str)
+            .try_init()
+            .unwrap_or(())
+    } else {
+        Builder::new()
+            .format(|buf, record| writeln!(buf, "{} [{}] - {}", Local::now().format("%Y-%m-%dT%H:%M:%S%.3f"), record.level(), record.args()))
+            .parse_filters(&filters_str)
+            .try_init()
+            .unwrap_or(())
+    }
 }
 
 pub fn create_new_ticket(login: &str, user_id: &str, duration: i64, ticket: &mut Ticket, storage: &mut VStorage) {
@@ -559,7 +579,9 @@ pub fn get_info_of_module(module_name: &str) -> Option<(i64, i64)> {
     info.read_info()
 }
 
-pub fn wait_load_ontology() -> i64 { wait_module("input-onto", 1) }
+pub fn wait_load_ontology() -> i64 {
+    wait_module("input-onto", 1)
+}
 
 pub fn wait_module(module_name: &str, wait_op_id: i64) -> i64 {
     if wait_op_id < 0 {
